@@ -1,21 +1,8 @@
 /*
-    <one line to give the library's name and an idea of what it does.>
-    Copyright (C) 2012  Vishesh Handa <me@vhanda.in>
-    Copyright (C) 2012  Jörg Ehrichs <joerg.ehrichs@gmx.de>
+    SPDX-FileCopyrightText: 2012 Vishesh Handa <me@vhanda.in>
+    SPDX-FileCopyrightText: 2012 Jörg Ehrichs <joerg.ehrichs@gmx.de>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 
@@ -123,18 +110,38 @@ QStringList ExtractorPlugin::contactsFromString(const QString& string)
     cleanedString = cleanedString.remove(QLatin1Char('{'));
     cleanedString = cleanedString.remove(QLatin1Char('}'));
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     QStringList contactStrings = string.split(QLatin1Char(','), QString::SkipEmptyParts);
+#else
+    QStringList contactStrings = string.split(QLatin1Char(','), Qt::SkipEmptyParts);
+#endif
     if (contactStrings.size() == 1)
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         contactStrings = string.split(QLatin1Char(';'), QString::SkipEmptyParts);
+#else
+        contactStrings = string.split(QLatin1Char(';'), Qt::SkipEmptyParts);
+#endif
 
     if (contactStrings.size() == 1)
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         contactStrings = string.split(QStringLiteral(" ft "), QString::SkipEmptyParts);
+#else
+        contactStrings = string.split(QStringLiteral(" ft "), Qt::SkipEmptyParts);
+#endif
 
     if (contactStrings.size() == 1)
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         contactStrings = string.split(QStringLiteral(" feat. "), QString::SkipEmptyParts);
+#else
+        contactStrings = string.split(QStringLiteral(" feat. "), Qt::SkipEmptyParts);
+#endif
 
     if (contactStrings.size() == 1)
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         contactStrings = string.split(QStringLiteral(" feat "), QString::SkipEmptyParts);
+#else
+        contactStrings = string.split(QStringLiteral(" feat "), Qt::SkipEmptyParts);
+#endif
 
     QStringList list;
     list.reserve(contactStrings.count());
